# Application Modeling Guidelines
### On this page
  * [Definition](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines#definition)
  * [Description](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines#description)
  * [Application Fact Sheet Subtypes](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines#application-fact-sheet-subtypes)
  * [Business Application](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines#business-application)
  * [Microservice](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines#microservice)
  * [AI Agent](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines#ai-agent)
  * [Best Practices for Getting Started](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines#best-practices-for-getting-started)
  * [Modeling SaaS Services](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines#modeling-saas-services)


View all
This page guides you on modeling applications, covering subtypes, best practices, versioning, hierarchies, and use cases. Avoid common antipatterns and gain valuable insights.
**Note**
These modeling guidelines are for the meta model v4. For meta model v3 guidelines, see [modeling guidelines for the Meta Model v3](https://help.sap.com/docs/leanix/ea/meta-model-v3?locale=en-US&state=PRODUCTION&version=CLOUD).
